==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/ImageSourcePathFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageSourcePathFluent<A extends ImageSourcePathFluent<A>> extends BaseFluent<A>{
  public ImageSourcePathFluent() {
  }
  
  public ImageSourcePathFluent(ImageSourcePath instance) {
    this.copyInstance(instance);
  }
  private String destinationDir;
  private String sourcePath;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageSourcePath instance) {
    instance = (instance != null ? instance : new ImageSourcePath());
  
    if (instance != null) {
        this.withDestinationDir(instance.getDestinationDir());
        this.withSourcePath(instance.getSourcePath());
        this.withDestinationDir(instance.getDestinationDir());
        this.withSourcePath(instance.getSourcePath());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getDestinationDir() {
    return this.destinationDir;
  }
  
  public A withDestinationDir(String destinationDir) {
    this.destinationDir=destinationDir; return (A) this;
  }
  
  public boolean hasDestinationDir() {
    return this.destinationDir != null;
  }
  
  public String getSourcePath() {
    return this.sourcePath;
  }
  
  public A withSourcePath(String sourcePath) {
    this.sourcePath=sourcePath; return (A) this;
  }
  
  public boolean hasSourcePath() {
    return this.sourcePath != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageSourcePathFluent that = (ImageSourcePathFluent) o;
    if (!java.util.Objects.equals(destinationDir, that.destinationDir)) return false;
  
    if (!java.util.Objects.equals(sourcePath, that.sourcePath)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(destinationDir,  sourcePath,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destinationDir != null) { sb.append("destinationDir:"); sb.append(destinationDir + ","); }
    if (sourcePath != null) { sb.append("sourcePath:"); sb.append(sourcePath + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-6.9.1-sources.jar: io/fabric8/openshift/api/model/ImageSourcePathFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageSourcePathFluent<A extends ImageSourcePathFluent<A>> extends BaseFluent<A>{
  public ImageSourcePathFluent() {
  }
  
  public ImageSourcePathFluent(ImageSourcePath instance) {
    this.copyInstance(instance);
  }
  private String destinationDir;
  private String sourcePath;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageSourcePath instance) {
    instance = (instance != null ? instance : new ImageSourcePath());
    if (instance != null) {
          this.withDestinationDir(instance.getDestinationDir());
          this.withSourcePath(instance.getSourcePath());
          this.withDestinationDir(instance.getDestinationDir());
          this.withSourcePath(instance.getSourcePath());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getDestinationDir() {
    return this.destinationDir;
  }
  
  public A withDestinationDir(String destinationDir) {
    this.destinationDir = destinationDir;
    return (A) this;
  }
  
  public boolean hasDestinationDir() {
    return this.destinationDir != null;
  }
  
  public String getSourcePath() {
    return this.sourcePath;
  }
  
  public A withSourcePath(String sourcePath) {
    this.sourcePath = sourcePath;
    return (A) this;
  }
  
  public boolean hasSourcePath() {
    return this.sourcePath != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageSourcePathFluent that = (ImageSourcePathFluent) o;
    if (!java.util.Objects.equals(destinationDir, that.destinationDir)) return false;
    if (!java.util.Objects.equals(sourcePath, that.sourcePath)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(destinationDir,  sourcePath,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destinationDir != null) { sb.append("destinationDir:"); sb.append(destinationDir + ","); }
    if (sourcePath != null) { sb.append("sourcePath:"); sb.append(sourcePath + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
